@@ -2,7 +2,6 @@
 -- Test domains.
 --
 -- Test Comment / Drop
-
 CREATE DOMAIN domaindroptest int4;
 
 COMMENT ON DOMAIN domaindroptest IS 'About to drop this..';
@@ -20,7 +19,6 @@ DROP DOMAIN domaindroptest CASCADE;
 -- Test domain input.
 -- Note: the point of checking both INSERT and COPY FROM is that INSERT
 -- exercises CoerceToDomain while COPY exercises domain_in.
-
 CREATE DOMAIN domainvarchar varchar(5);
 
 CREATE DOMAIN domainnumeric numeric(8, 2);
@@ -31,10 +29,10 @@ CREATE DOMAIN domaintext text;
 
 -- Test explicit coercions --- these should succeed (and truncate)
 SELECT
-    CAST('123456' AS domainvarchar);
+    cast('123456' AS domainvarchar);
 
 SELECT
-    CAST('12345' AS domainvarchar);
+    cast('12345' AS domainvarchar);
 
 -- Test tables using domains
 CREATE TABLE basictest (
@@ -490,7 +488,7 @@ INSERT INTO pitable
     VALUES (ARRAY[42]);
 
 INSERT INTO pitable
-    VALUES (ARRAY[- 1]);
+    VALUES (ARRAY[-1]);
 
 -- fail
 INSERT INTO pitable
@@ -625,8 +623,7 @@ NOT NULL CHECK (VALUE = 'a'
 
 CREATE TABLE nulltest (
     col1 dnotnull,
-    col2 dnotnull NULL -- NOT NULL in the domain cannot be overridden
-,
+    col2 dnotnull NULL, -- NOT NULL in the domain cannot be overridden
     col3 dnull NOT NULL,
     col4 dnull,
     col5 dcheck CHECK (col5 IN ('c', 'd'))
@@ -662,24 +659,23 @@ FROM
 
 -- Test out coerced (casted) constraints
 SELECT
-    CAST('1' AS dnotnull);
+    cast('1' AS dnotnull);
 
 SELECT
-    CAST(NULL AS dnotnull);
+    cast(NULL AS dnotnull);
 
 -- fail
 SELECT
-    CAST(CAST(NULL AS dnull) AS dnotnull);
+    cast(cast(NULL AS dnull) AS dnotnull);
 
 -- fail
 SELECT
-    CAST(col4 AS dnotnull)
+    cast(col4 AS dnotnull)
 FROM
     nulltest;
 
 -- fail
 -- cleanup
-
 DROP TABLE nulltest;
 
 DROP DOMAIN dnotnull RESTRICT;
@@ -722,7 +718,6 @@ ALTER TABLE defaulttest
 
 INSERT INTO defaulttest DEFAULT VALUES; -- succeeds, inserts domain default
 -- We used to treat SET DEFAULT NULL as equivalent to DROP DEFAULT; wrong
-
 ALTER TABLE defaulttest
     ALTER COLUMN col5 SET DEFAULT NULL;
 
@@ -835,7 +830,7 @@ ALTER DOMAIN con
     ADD CHECK (VALUE > 0);
 
 INSERT INTO domcontest
-    VALUES (- 5);
+    VALUES (-5);
 
 -- fails
 INSERT INTO domcontest
@@ -849,7 +844,7 @@ ALTER DOMAIN con
     DROP CONSTRAINT t;
 
 INSERT INTO domcontest
-    VALUES (- 5);
+    VALUES (-5);
 
 --fails
 INSERT INTO domcontest
@@ -862,7 +857,7 @@ ALTER DOMAIN con
     DROP CONSTRAINT IF EXISTS nonexistent;
 
 -- Test ALTER DOMAIN .. CONSTRAINT .. NOT VALID
-CREATE DOMAIN things AS int;
+CREATE DOMAIN things AS INT;
 
 CREATE TABLE thethings (
     stuff things
@@ -895,7 +890,7 @@ CREATE DOMAIN dom AS integer;
 
 CREATE VIEW domview AS
 SELECT
-    CAST(col1 AS dom)
+    cast(col1 AS dom)
 FROM
     domtab;
 
@@ -1019,7 +1014,6 @@ DROP DOMAIN vchar4 CASCADE;
 -- Make sure that constraints of newly-added domain columns are
 -- enforced correctly, even if there's no default value for the new
 -- column. Per bug #1433
-
 CREATE DOMAIN str_domain AS text NOT NULL;
 
 CREATE TABLE domain_test (
@@ -1046,7 +1040,6 @@ ALTER TABLE domain_test
 
 -- Check that domain constraints on prepared statement parameters of
 -- unknown type are enforced correctly.
-
 CREATE DOMAIN pos_int AS int4 CHECK (value > 0)
 NOT NULL;
 
@@ -1064,7 +1057,6 @@ EXECUTE s1 (NULL);
 -- should fail
 -- Check that domain constraints on plpgsql function parameters, results,
 -- and local variables are enforced correctly.
-
 CREATE FUNCTION doubledecrement (p1 pos_int)
     RETURNS pos_int
     AS $$
@@ -1128,7 +1120,6 @@ SELECT
 
 -- good
 -- Check that ALTER DOMAIN tests columns of derived types
-
 CREATE DOMAIN posint AS int4;
 
 -- Currently, this doesn't work for composite types, but verify it complains
@@ -1141,7 +1132,7 @@ CREATE TABLE ddtest2 (
 );
 
 INSERT INTO ddtest2
-    VALUES (ROW (- 1));
+    VALUES (ROW (-1));
 
 ALTER DOMAIN posint
     ADD CONSTRAINT c1 CHECK (value >= 0);
@@ -1228,7 +1219,7 @@ INSERT INTO ddtest2
 
 -- fail
 INSERT INTO ddtest2
-    VALUES (- 2);
+    VALUES (-2);
 
 -- fail
 INSERT INTO ddtest2
@@ -1251,7 +1242,6 @@ DROP DOMAIN posint CASCADE;
 --
 -- Check enforcement of domain-related typmod in plpgsql (bug #5717)
 --
-
 CREATE OR REPLACE FUNCTION array_elem_check (numeric)
     RETURNS numeric
     AS $$
@@ -1315,7 +1305,6 @@ DROP FUNCTION array_elem_check (numeric);
 --
 -- Check enforcement of array-level domain constraints
 --
-
 CREATE DOMAIN orderedpair AS int[2] CHECK (value[1] < value[2]);
 
 SELECT
@@ -1368,14 +1357,13 @@ SELECT
     array_elem_check (3);
 
 SELECT
-    array_elem_check (- 1);
+    array_elem_check (-1);
 
 DROP FUNCTION array_elem_check (int);
 
 --
 -- Check enforcement of changing constraints in plpgsql
 --
-
 CREATE DOMAIN di AS int;
 
 CREATE FUNCTION dom_check (int)
@@ -1445,7 +1433,6 @@ DROP DOMAIN di;
 -- Check use of a (non-inline-able) SQL function in a domain constraint;
 -- this has caused issues in the past
 --
-
 CREATE FUNCTION sql_is_distinct_from (anyelement, anyelement)
     RETURNS boolean
     LANGUAGE sql
@@ -1482,7 +1469,6 @@ DROP FUNCTION sql_is_distinct_from (anyelement, anyelement);
 --
 -- Renaming
 --
-
 CREATE DOMAIN testdomain1 AS int;
 
 ALTER DOMAIN testdomain1 RENAME TO testdomain2;
@@ -1495,7 +1481,6 @@ DROP DOMAIN testdomain3;
 --
 -- Renaming domain constraints
 --
-
 CREATE DOMAIN testdomain1 AS int CONSTRAINT unsigned CHECK (value > 0);
 
 ALTER DOMAIN testdomain1 RENAME CONSTRAINT unsigned TO unsigned_foo;
