@@ -148,7 +148,7 @@ INSERT INTO T
     VALUES (11), (12);
 
 ALTER TABLE T
-    ADD COLUMN c_small SMALLINT DEFAULT - 5,
+    ADD COLUMN c_small SMALLINT DEFAULT -5,
     ADD COLUMN c_small_null SMALLINT,
     ALTER COLUMN c_array SET DEFAULT '{"This", "is", "no", "fantasy"}';
 
@@ -165,7 +165,7 @@ INSERT INTO T
 
 ALTER TABLE T
     ADD COLUMN c_num NUMERIC DEFAULT 1.00000000001,
-    ALTER COLUMN c_big SET DEFAULT - 9999999999999999;
+    ALTER COLUMN c_big SET DEFAULT -9999999999999999;
 
 INSERT INTO T
     VALUES (17), (18);
@@ -377,7 +377,7 @@ FROM
     generate_series(1, 10) a;
 
 ALTER TABLE T
-    ADD COLUMN c_bigint BIGINT NOT NULL DEFAULT - 1;
+    ADD COLUMN c_bigint BIGINT NOT NULL DEFAULT -1;
 
 INSERT INTO T
 SELECT
@@ -561,7 +561,7 @@ INSERT INTO T
     VALUES (1), (2);
 
 ALTER TABLE T
-    ADD COLUMN c_int INT NOT NULL DEFAULT - 1;
+    ADD COLUMN c_int INT NOT NULL DEFAULT -1;
 
 INSERT INTO T
     VALUES (3), (4);
@@ -628,7 +628,7 @@ CREATE FUNCTION test_trigger ()
     LANGUAGE plpgsql
     AS $$
 BEGIN
-    RAISE notice 'old tuple: %', to_json(OLD)::text;
+    RAISE NOTICE 'old tuple: %', to_json(OLD)::text;
     IF TG_OP = 'DELETE' THEN
         RETURN OLD;
     ELSE
