@@ -3,7 +3,6 @@
 --
 -- Clean up in case a prior regression run failed
 -- Suppress NOTICE messages when roles don't exist
-
 SET client_min_messages TO 'warning';
 
 DROP ROLE IF EXISTS regress_foreign_data_user, regress_test_role, regress_test_role2, regress_test_role_super, regress_test_indirect, regress_unprivileged_role;
@@ -1017,7 +1016,8 @@ RESET ROLE;
 SELECT
     has_foreign_data_wrapper_privilege('regress_test_role', (
             SELECT
-                oid FROM pg_foreign_data_wrapper
+                oid
+            FROM pg_foreign_data_wrapper
             WHERE
                 fdwname = 'foo'), 'USAGE');
 
@@ -1027,25 +1027,29 @@ SELECT
 SELECT
     has_foreign_data_wrapper_privilege((
         SELECT
-            oid FROM pg_roles
+            oid
+        FROM pg_roles
         WHERE
             rolname = 'regress_test_role'), (
         SELECT
-            oid FROM pg_foreign_data_wrapper
+            oid
+        FROM pg_foreign_data_wrapper
         WHERE
             fdwname = 'foo'), 'USAGE');
 
 SELECT
     has_foreign_data_wrapper_privilege((
         SELECT
-            oid FROM pg_foreign_data_wrapper
+            oid
+        FROM pg_foreign_data_wrapper
         WHERE
             fdwname = 'foo'), 'USAGE');
 
 SELECT
     has_foreign_data_wrapper_privilege((
         SELECT
-            oid FROM pg_roles
+            oid
+        FROM pg_roles
         WHERE
             rolname = 'regress_test_role'), 'foo', 'USAGE');
 
@@ -1061,7 +1065,8 @@ SELECT
 SELECT
     has_server_privilege('regress_test_role', (
             SELECT
-                oid FROM pg_foreign_server
+                oid
+            FROM pg_foreign_server
             WHERE
                 srvname = 's8'), 'USAGE');
 
@@ -1071,25 +1076,29 @@ SELECT
 SELECT
     has_server_privilege((
         SELECT
-            oid FROM pg_roles
+            oid
+        FROM pg_roles
         WHERE
             rolname = 'regress_test_role'), (
         SELECT
-            oid FROM pg_foreign_server
+            oid
+        FROM pg_foreign_server
         WHERE
             srvname = 's8'), 'USAGE');
 
 SELECT
     has_server_privilege((
         SELECT
-            oid FROM pg_foreign_server
+            oid
+        FROM pg_foreign_server
         WHERE
             srvname = 's8'), 'USAGE');
 
 SELECT
     has_server_privilege((
         SELECT
-            oid FROM pg_roles
+            oid
+        FROM pg_roles
         WHERE
             rolname = 'regress_test_role'), 's8', 'USAGE');
 
@@ -1245,7 +1254,6 @@ DROP SERVER s9 CASCADE;
 
 -- ERROR
 -- Check visibility of user mapping data
-
 SET ROLE regress_test_role;
 
 CREATE SERVER s10 FOREIGN DATA WRAPPER foo;
@@ -1578,7 +1586,6 @@ FROM
 
 -- ERROR
 -- DROP FOREIGN TABLE
-
 DROP FOREIGN TABLE no_table;
 
 -- ERROR
@@ -1710,7 +1717,6 @@ DROP TABLE fd_pt2;
 
 -- foreign table cannot be part of partition tree made of temporary
 -- relations.
-
 CREATE TEMP TABLE temp_parted (
     a int
 )
