@@ -1525,7 +1525,8 @@ SELECT
                     row_to_json(r)
                 FROM (
                     SELECT
-                        relkind, oid::regclass AS name FROM pg_class
+                        relkind, oid::regclass AS name
+                    FROM pg_class
                     WHERE
                         relname = 'pg_class') r)));
 
@@ -1625,12 +1626,12 @@ INSERT INTO foo
     VALUES (847003, 'sub-alpha', 'GESS90');
 
 SELECT
-    json_build_object('turbines', json_object_agg(serial_num, json_build_object('name', name, 'type', TYPE)))
+    json_build_object('turbines', json_object_agg(serial_num, json_build_object('name', name, 'type', type)))
 FROM
     foo;
 
 SELECT
-    json_object_agg(name, TYPE)
+    json_object_agg(name, type)
 FROM
     foo;
 
@@ -1638,7 +1639,7 @@ INSERT INTO foo
     VALUES (999999, NULL, 'bar');
 
 SELECT
-    json_object_agg(name, TYPE)
+    json_object_agg(name, type)
 FROM
     foo;
 
