@@ -919,7 +919,7 @@ CREATE FUNCTION bleat (int)
     RETURNS int
     AS $$
 BEGIN
-    RAISE notice 'bleat %', $1;
+    RAISE NOTICE 'bleat %', $1;
     RETURN $1;
 END
 $$
@@ -1092,10 +1092,10 @@ SELECT
 -- fail
 -- test with variadic call parameter
 SELECT
-    myleast (VARIADIC ARRAY[1, 2, 3, 4, - 1]);
+    myleast (VARIADIC ARRAY[1, 2, 3, 4, -1]);
 
 SELECT
-    myleast (VARIADIC ARRAY[1.1, - 5.5]);
+    myleast (VARIADIC ARRAY[1.1, -5.5]);
 
 --test with empty variadic call parameter
 SELECT
@@ -1238,8 +1238,7 @@ $$
 LANGUAGE sql;
 
 -- however, this should work:
-CREATE FUNCTION dfunc (a int = 1, out sum int, b int = 2
-)
+CREATE FUNCTION dfunc (a int = 1, out sum int, b int = 2)
 AS $$
     SELECT
         $1 + $2;
