@@ -24,16 +24,16 @@ SELECT
 
 SELECT
     U & ' \' UESCAPE ' ! ' AS "tricky";
-SELECT ' tricky ' AS U&"\" UESCAPE ' ! ';
+SELECT 'tricky' AS U&"\" UESCAPE '!';
 
-SELECT U&' wrong: 061 ';
-SELECT U&' wrong: + 0061 ';
-SELECT U&' wrong: + 0061 ' UESCAPE ' + ';
+SELECT U&'wrong: \061';
+SELECT U&'wrong: \+0061';
+SELECT U&'wrong: +0061' UESCAPE '+';
 
 SET standard_conforming_strings TO off;
 
-SELECT U&' d 0061t + 000061 ' AS U&"d\0061t\+000061";
-SELECT U&' d ! 0061t + 000061 ' UESCAPE ' ! ' AS U&"d*0061t\+000061" UESCAPE ' * ';
+SELECT U&'d\0061t\+000061' AS U&"d\0061t\+000061";
+SELECT U&'d!0061t\+000061' UESCAPE '!' AS U&"d*0061t\+000061" UESCAPE '*';
 
 SELECT U&' \' UESCAPE '!' AS "tricky";
 
@@ -72,27 +72,27 @@ SELECT E'De\\123dBeEf'::bytea;
 -- E021-10 implicit casting among the character data types
 --
 
-SELECT CAST(f1 AS text) AS " text(char) " FROM CHAR_TBL;
+SELECT CAST(f1 AS text) AS "text(char)" FROM CHAR_TBL;
 
-SELECT CAST(f1 AS text) AS " text(varchar) " FROM VARCHAR_TBL;
+SELECT CAST(f1 AS text) AS "text(varchar)" FROM VARCHAR_TBL;
 
-SELECT CAST(name 'namefield' AS text) AS " text(name) ";
+SELECT CAST(name 'namefield' AS text) AS "text(name)";
 
 -- since this is an explicit cast, it should truncate w/o error:
-SELECT CAST(f1 AS char(10)) AS " char(text) " FROM TEXT_TBL;
+SELECT CAST(f1 AS char(10)) AS "char(text)" FROM TEXT_TBL;
 -- note: implicit-cast case is tested in char.sql
 
-SELECT CAST(f1 AS char(20)) AS " char(text) " FROM TEXT_TBL;
+SELECT CAST(f1 AS char(20)) AS "char(text)" FROM TEXT_TBL;
 
-SELECT CAST(f1 AS char(10)) AS " char(varchar) " FROM VARCHAR_TBL;
+SELECT CAST(f1 AS char(10)) AS "char(varchar)" FROM VARCHAR_TBL;
 
-SELECT CAST(name 'namefield' AS char(10)) AS " char(name) ";
+SELECT CAST(name 'namefield' AS char(10)) AS "char(name)";
 
-SELECT CAST(f1 AS varchar) AS " varchar(text) " FROM TEXT_TBL;
+SELECT CAST(f1 AS varchar) AS "varchar(text)" FROM TEXT_TBL;
 
-SELECT CAST(f1 AS varchar) AS " varchar(char) " FROM CHAR_TBL;
+SELECT CAST(f1 AS varchar) AS "varchar(char)" FROM CHAR_TBL;
 
-SELECT CAST(name 'namefield' AS varchar) AS " varchar(name) ";
+SELECT CAST(name 'namefield' AS varchar) AS "varchar(name)";
 
 --
 -- test SQL string functions
@@ -100,36 +100,36 @@ SELECT CAST(name 'namefield' AS varchar) AS " varchar(name) ";
 --
 
 -- E021-09 trim function
-SELECT TRIM(BOTH FROM '  bunch o blanks  ') = 'bunch o blanks' AS " bunch o blanks ";
+SELECT TRIM(BOTH FROM '  bunch o blanks  ') = 'bunch o blanks' AS "bunch o blanks";
 
-SELECT TRIM(LEADING FROM '  bunch o blanks  ') = 'bunch o blanks  ' AS " bunch o blanks ";
+SELECT TRIM(LEADING FROM '  bunch o blanks  ') = 'bunch o blanks  ' AS "bunch o blanks  ";
 
-SELECT TRIM(TRAILING FROM '  bunch o blanks  ') = '  bunch o blanks' AS " bunch o blanks ";
+SELECT TRIM(TRAILING FROM '  bunch o blanks  ') = '  bunch o blanks' AS "  bunch o blanks";
 
-SELECT TRIM(BOTH 'x' FROM 'xxxxxsome Xsxxxxx') = 'some Xs' AS " SOME Xs ";
+SELECT TRIM(BOTH 'x' FROM 'xxxxxsome Xsxxxxx') = 'some Xs' AS "some Xs";
 
 -- E021-06 substring expression
-SELECT SUBSTRING('1234567890' FROM 3) = '34567890' AS " 34567890 ";
+SELECT SUBSTRING('1234567890' FROM 3) = '34567890' AS "34567890";
 
-SELECT SUBSTRING('1234567890' FROM 4 FOR 3) = '456' AS " 456 ";
+SELECT SUBSTRING('1234567890' FROM 4 FOR 3) = '456' AS "456";
 
 -- T581 regular expression substring (with SQL99's bizarre regexp syntax)
-SELECT SUBSTRING('abcdefg' FROM 'a#" (b_d) # "%' FOR '#') AS " bcd ";
+SELECT SUBSTRING('abcdefg' FROM 'a#"(b_d)#"%' FOR '#') AS "bcd";
 
 -- No match should return NULL
-SELECT SUBSTRING('abcdefg' FROM '#" (b_d) # "%' FOR '#') IS NULL AS " TRUE ";
+SELECT SUBSTRING('abcdefg' FROM '#"(b_d)#"%' FOR '#') IS NULL AS "True";
 
 -- Null inputs should return NULL
-SELECT SUBSTRING('abcdefg' FROM '(b|c)' FOR NULL) IS NULL AS " TRUE ";
-SELECT SUBSTRING(NULL FROM '(b|c)' FOR '#') IS NULL AS " TRUE ";
-SELECT SUBSTRING('abcdefg' FROM NULL FOR '#') IS NULL AS " TRUE ";
+SELECT SUBSTRING('abcdefg' FROM '(b|c)' FOR NULL) IS NULL AS "True";
+SELECT SUBSTRING(NULL FROM '(b|c)' FOR '#') IS NULL AS "True";
+SELECT SUBSTRING('abcdefg' FROM NULL FOR '#') IS NULL AS "True";
 
 -- PostgreSQL extension to allow omitting the escape character;
 -- here the regexp is taken as Posix syntax
-SELECT SUBSTRING('abcdefg' FROM 'c.e') AS " cde ";
+SELECT SUBSTRING('abcdefg' FROM 'c.e') AS "cde";
 
 -- With a parenthesized subexpression, return only what matches the subexpr
-SELECT SUBSTRING('abcdefg' FROM 'b(.*)f') AS " cde ";
+SELECT SUBSTRING('abcdefg' FROM 'b(.*)f') AS "cde";
 
 -- PostgreSQL extension to allow using back reference in replace string;
 SELECT regexp_replace('1112223333', E'(\\d{3})(\\d{3})(\\d{4})', E'(\\1) \\2-\\3');
@@ -205,18 +205,18 @@ SELECT regexp_split_to_array('thE QUick bROWn FOx jUMPs ovEr The lazy dOG', 'e',
 \pset null ''
 
 -- E021-11 position expression
-SELECT POSITION('4' IN '1234567890') = '4' AS " 4 ";
+SELECT POSITION('4' IN '1234567890') = '4' AS "4";
 
-SELECT POSITION('5' IN '1234567890') = '5' AS " 5 ";
+SELECT POSITION('5' IN '1234567890') = '5' AS "5";
 
 -- T312 character overlay function
-SELECT OVERLAY('abcdef' PLACING '45' FROM 4) AS " abc45f ";
+SELECT OVERLAY('abcdef' PLACING '45' FROM 4) AS "abc45f";
 
-SELECT OVERLAY('yabadoo' PLACING 'daba' FROM 5) AS " yabadaba ";
+SELECT OVERLAY('yabadoo' PLACING 'daba' FROM 5) AS "yabadaba";
 
-SELECT OVERLAY('yabadoo' PLACING 'daba' FROM 5 FOR 0) AS " yabadabadoo ";
+SELECT OVERLAY('yabadoo' PLACING 'daba' FROM 5 FOR 0) AS "yabadabadoo";
 
-SELECT OVERLAY('babosa' PLACING 'ubb' FROM 2 FOR 4) AS " bubba ";
+SELECT OVERLAY('babosa' PLACING 'ubb' FROM 2 FOR 4) AS "bubba";
 
 --
 -- test LIKE
@@ -225,75 +225,75 @@ SELECT OVERLAY('babosa' PLACING 'ubb' FROM 2 FOR 4) AS " bubba ";
 
 -- simplest examples
 -- E061-04 like predicate
-SELECT 'hawkeye' LIKE 'h%' AS " TRUE ";
-SELECT 'hawkeye' NOT LIKE 'h%' AS " FALSE ";
+SELECT 'hawkeye' LIKE 'h%' AS "true";
+SELECT 'hawkeye' NOT LIKE 'h%' AS "false";
 
-SELECT 'hawkeye' LIKE 'H%' AS " FALSE ";
-SELECT 'hawkeye' NOT LIKE 'H%' AS " TRUE ";
+SELECT 'hawkeye' LIKE 'H%' AS "false";
+SELECT 'hawkeye' NOT LIKE 'H%' AS "true";
 
-SELECT 'hawkeye' LIKE 'indio%' AS " FALSE ";
-SELECT 'hawkeye' NOT LIKE 'indio%' AS " TRUE ";
+SELECT 'hawkeye' LIKE 'indio%' AS "false";
+SELECT 'hawkeye' NOT LIKE 'indio%' AS "true";
 
-SELECT 'hawkeye' LIKE 'h%eye' AS " TRUE ";
-SELECT 'hawkeye' NOT LIKE 'h%eye' AS " FALSE ";
+SELECT 'hawkeye' LIKE 'h%eye' AS "true";
+SELECT 'hawkeye' NOT LIKE 'h%eye' AS "false";
 
-SELECT 'indio' LIKE '_ndio' AS " TRUE ";
-SELECT 'indio' NOT LIKE '_ndio' AS " FALSE ";
+SELECT 'indio' LIKE '_ndio' AS "true";
+SELECT 'indio' NOT LIKE '_ndio' AS "false";
 
-SELECT 'indio' LIKE 'in__o' AS " TRUE ";
-SELECT 'indio' NOT LIKE 'in__o' AS " FALSE ";
+SELECT 'indio' LIKE 'in__o' AS "true";
+SELECT 'indio' NOT LIKE 'in__o' AS "false";
 
-SELECT 'indio' LIKE 'in_o' AS " FALSE ";
-SELECT 'indio' NOT LIKE 'in_o' AS " TRUE ";
+SELECT 'indio' LIKE 'in_o' AS "false";
+SELECT 'indio' NOT LIKE 'in_o' AS "true";
 
 -- unused escape character
-SELECT 'hawkeye' LIKE 'h%' ESCAPE '#' AS " TRUE ";
-SELECT 'hawkeye' NOT LIKE 'h%' ESCAPE '#' AS " FALSE ";
+SELECT 'hawkeye' LIKE 'h%' ESCAPE '#' AS "true";
+SELECT 'hawkeye' NOT LIKE 'h%' ESCAPE '#' AS "false";
 
-SELECT 'indio' LIKE 'ind_o' ESCAPE '$' AS " TRUE ";
-SELECT 'indio' NOT LIKE 'ind_o' ESCAPE '$' AS " FALSE ";
+SELECT 'indio' LIKE 'ind_o' ESCAPE '$' AS "true";
+SELECT 'indio' NOT LIKE 'ind_o' ESCAPE '$' AS "false";
 
 -- escape character
 -- E061-05 like predicate with escape clause
-SELECT 'h%' LIKE 'h#%' ESCAPE '#' AS " TRUE ";
-SELECT 'h%' NOT LIKE 'h#%' ESCAPE '#' AS " FALSE ";
+SELECT 'h%' LIKE 'h#%' ESCAPE '#' AS "true";
+SELECT 'h%' NOT LIKE 'h#%' ESCAPE '#' AS "false";
 
-SELECT 'h%wkeye' LIKE 'h#%' ESCAPE '#' AS " FALSE ";
-SELECT 'h%wkeye' NOT LIKE 'h#%' ESCAPE '#' AS " TRUE ";
+SELECT 'h%wkeye' LIKE 'h#%' ESCAPE '#' AS "false";
+SELECT 'h%wkeye' NOT LIKE 'h#%' ESCAPE '#' AS "true";
 
-SELECT 'h%wkeye' LIKE 'h#%%' ESCAPE '#' AS " TRUE ";
-SELECT 'h%wkeye' NOT LIKE 'h#%%' ESCAPE '#' AS " FALSE ";
+SELECT 'h%wkeye' LIKE 'h#%%' ESCAPE '#' AS "true";
+SELECT 'h%wkeye' NOT LIKE 'h#%%' ESCAPE '#' AS "false";
 
-SELECT 'h%awkeye' LIKE 'h#%a%k%e' ESCAPE '#' AS " TRUE ";
-SELECT 'h%awkeye' NOT LIKE 'h#%a%k%e' ESCAPE '#' AS " FALSE ";
+SELECT 'h%awkeye' LIKE 'h#%a%k%e' ESCAPE '#' AS "true";
+SELECT 'h%awkeye' NOT LIKE 'h#%a%k%e' ESCAPE '#' AS "false";
 
-SELECT 'indio' LIKE '_ndio' ESCAPE '$' AS " TRUE ";
-SELECT 'indio' NOT LIKE '_ndio' ESCAPE '$' AS " FALSE ";
+SELECT 'indio' LIKE '_ndio' ESCAPE '$' AS "true";
+SELECT 'indio' NOT LIKE '_ndio' ESCAPE '$' AS "false";
 
-SELECT 'i_dio' LIKE 'i$_d_o' ESCAPE '$' AS " TRUE ";
-SELECT 'i_dio' NOT LIKE 'i$_d_o' ESCAPE '$' AS " FALSE ";
+SELECT 'i_dio' LIKE 'i$_d_o' ESCAPE '$' AS "true";
+SELECT 'i_dio' NOT LIKE 'i$_d_o' ESCAPE '$' AS "false";
 
-SELECT 'i_dio' LIKE 'i$_nd_o' ESCAPE '$' AS " FALSE ";
-SELECT 'i_dio' NOT LIKE 'i$_nd_o' ESCAPE '$' AS " TRUE ";
+SELECT 'i_dio' LIKE 'i$_nd_o' ESCAPE '$' AS "false";
+SELECT 'i_dio' NOT LIKE 'i$_nd_o' ESCAPE '$' AS "true";
 
-SELECT 'i_dio' LIKE 'i$_d%o' ESCAPE '$' AS " TRUE ";
-SELECT 'i_dio' NOT LIKE 'i$_d%o' ESCAPE '$' AS " FALSE ";
+SELECT 'i_dio' LIKE 'i$_d%o' ESCAPE '$' AS "true";
+SELECT 'i_dio' NOT LIKE 'i$_d%o' ESCAPE '$' AS "false";
 
 -- escape character same as pattern character
-SELECT 'maca' LIKE 'm%aca' ESCAPE '%' AS " TRUE ";
-SELECT 'maca' NOT LIKE 'm%aca' ESCAPE '%' AS " FALSE ";
+SELECT 'maca' LIKE 'm%aca' ESCAPE '%' AS "true";
+SELECT 'maca' NOT LIKE 'm%aca' ESCAPE '%' AS "false";
 
-SELECT 'ma%a' LIKE 'm%a%%a' ESCAPE '%' AS " TRUE ";
-SELECT 'ma%a' NOT LIKE 'm%a%%a' ESCAPE '%' AS " FALSE ";
+SELECT 'ma%a' LIKE 'm%a%%a' ESCAPE '%' AS "true";
+SELECT 'ma%a' NOT LIKE 'm%a%%a' ESCAPE '%' AS "false";
 
-SELECT 'bear' LIKE 'b_ear' ESCAPE '_' AS " TRUE ";
-SELECT 'bear' NOT LIKE 'b_ear' ESCAPE '_' AS " FALSE ";
+SELECT 'bear' LIKE 'b_ear' ESCAPE '_' AS "true";
+SELECT 'bear' NOT LIKE 'b_ear' ESCAPE '_' AS "false";
 
-SELECT 'be_r' LIKE 'b_e__r' ESCAPE '_' AS " TRUE ";
-SELECT 'be_r' NOT LIKE 'b_e__r' ESCAPE '_' AS " FALSE ";
+SELECT 'be_r' LIKE 'b_e__r' ESCAPE '_' AS "true";
+SELECT 'be_r' NOT LIKE 'b_e__r' ESCAPE '_' AS "false";
 
-SELECT 'be_r' LIKE '__e__r' ESCAPE '_' AS " FALSE ";
-SELECT 'be_r' NOT LIKE '__e__r' ESCAPE '_' AS " TRUE ";
+SELECT 'be_r' LIKE '__e__r' ESCAPE '_' AS "false";
+SELECT 'be_r' NOT LIKE '__e__r' ESCAPE '_' AS "true";
 
 
 --
@@ -301,17 +301,17 @@ SELECT 'be_r' NOT LIKE '__e__r' ESCAPE '_' AS " TRUE ";
 -- Be sure to form every test as an ILIKE/NOT ILIKE pair.
 --
 
-SELECT 'hawkeye' ILIKE 'h%' AS " TRUE ";
-SELECT 'hawkeye' NOT ILIKE 'h%' AS " FALSE ";
+SELECT 'hawkeye' ILIKE 'h%' AS "true";
+SELECT 'hawkeye' NOT ILIKE 'h%' AS "false";
 
-SELECT 'hawkeye' ILIKE 'H%' AS " TRUE ";
-SELECT 'hawkeye' NOT ILIKE 'H%' AS " FALSE ";
+SELECT 'hawkeye' ILIKE 'H%' AS "true";
+SELECT 'hawkeye' NOT ILIKE 'H%' AS "false";
 
-SELECT 'hawkeye' ILIKE 'H%Eye' AS " TRUE ";
-SELECT 'hawkeye' NOT ILIKE 'H%Eye' AS " FALSE ";
+SELECT 'hawkeye' ILIKE 'H%Eye' AS "true";
+SELECT 'hawkeye' NOT ILIKE 'H%Eye' AS "false";
 
-SELECT 'Hawkeye' ILIKE 'h%' AS " TRUE ";
-SELECT 'Hawkeye' NOT ILIKE 'h%' AS " FALSE ";
+SELECT 'Hawkeye' ILIKE 'h%' AS "true";
+SELECT 'Hawkeye' NOT ILIKE 'h%' AS "false";
 
 --
 -- test %/_ combination cases, cf bugs #4821 and #5478
@@ -344,15 +344,15 @@ DROP TABLE texttest, byteatest;
 --
 
 -- E021-07 character concatenation
-SELECT 'unknown' || ' and unknown' AS " || unknown types ";
+SELECT 'unknown' || ' and unknown' AS "Concat unknown types";
 
-SELECT text 'text' || ' and unknown' AS " || text TO unknown TYPE ";
+SELECT text 'text' || ' and unknown' AS "Concat text to unknown type";
 
-SELECT char(20) 'characters' || ' and text' AS " || char TO unknown TYPE ";
+SELECT char(20) 'characters' || ' and text' AS "Concat char to unknown type";
 
-SELECT text 'text' || char(20) ' and characters' AS " || text TO char ";
+SELECT text 'text' || char(20) ' and characters' AS "Concat text to char";
 
-SELECT text 'text' || varchar ' and varchar' AS " || text TO varchar ";
+SELECT text 'text' || varchar ' and varchar' AS "Concat text to varchar";
 
 --
 -- test substr with toasted text values
@@ -424,108 +424,157 @@ insert into toasttest values(decode(repeat('1234567890',10000),'escape'));
 
 -- If the starting position is zero or less, then return from the start of the string
 -- adjusting the length to be consistent with the " negative START " per SQL.
-SELECT substr(f1, -1, 5) from toasttest;
+    SELECT
+        substr(f1, -1, 5)
+    FROM
+        toasttest;
 
 -- If the length is less than zero, an ERROR is thrown.
-SELECT substr(f1, 5, -1) from toasttest;
+SELECT
+    substr(f1, 5, -1)
+FROM
+    toasttest;
 
 -- If no third argument (length) is provided, the length to the end of the
 -- string is assumed.
-SELECT substr(f1, 99995) from toasttest;
+SELECT
+    substr(f1, 99995)
+FROM
+    toasttest;
 
 -- If start plus length is > string length, the result is truncated to
 -- string length
-SELECT substr(f1, 99995, 10) from toasttest;
+SELECT
+    substr(f1, 99995, 10)
+FROM
+    toasttest;
 
 DROP TABLE toasttest;
 
 -- test internally compressing datums
-
 -- this tests compressing a datum to a very small size which exercises a
 -- corner case in packed-varlena handling: even though small, the compressed
 -- datum must be given a 4-byte header because there are no bits to indicate
 -- compression in a 1-byte header
+CREATE TABLE toasttest (
+    c char(4096)
+);
+
+INSERT INTO toasttest
+    VALUES ('x');
+
+SELECT
+    length(c),
+    c::text
+FROM
+    toasttest;
+
+SELECT
+    c
+FROM
+    toasttest;
 
-CREATE TABLE toasttest (c char(4096));
-INSERT INTO toasttest VALUES('x');
-SELECT length(c), c::text FROM toasttest;
-SELECT c FROM toasttest;
 DROP TABLE toasttest;
 
 --
 -- test length
 --
-
-SELECT length('abcdef') AS " length_6 ";
+SELECT
+    length('abcdef') AS "length_6";
 
 --
 -- test strpos
 --
+SELECT
+    strpos('abcdef', 'cd') AS "pos_3";
 
-SELECT strpos('abcdef', 'cd') AS " pos_3 ";
-
-SELECT strpos('abcdef', 'xy') AS " pos_0 ";
+SELECT
+    strpos('abcdef', 'xy') AS "pos_0";
 
 --
 -- test replace
 --
-SELECT replace('abcdef', 'de', '45') AS " abc45f ";
+SELECT
+    replace('abcdef', 'de', '45') AS "abc45f";
 
-SELECT replace('yabadabadoo', 'ba', '123') AS " ya123da123doo ";
+SELECT
+    replace('yabadabadoo', 'ba', '123') AS "ya123da123doo";
 
-SELECT replace('yabadoo', 'bad', '') AS " yaoo ";
+SELECT
+    replace('yabadoo', 'bad', '') AS "yaoo";
 
 --
 -- test split_part
 --
-select split_part('joeuser@mydatabase','@',0) AS " an error ";
+SELECT
+    split_part('joeuser@mydatabase', '@', 0) AS "an error";
 
-select split_part('joeuser@mydatabase','@',1) AS " joeuser ";
+SELECT
+    split_part('joeuser@mydatabase', '@', 1) AS "joeuser";
 
-select split_part('joeuser@mydatabase','@',2) AS " mydatabase ";
+SELECT
+    split_part('joeuser@mydatabase', '@', 2) AS "mydatabase";
 
-select split_part('joeuser@mydatabase','@',3) AS " empty string ";
+SELECT
+    split_part('joeuser@mydatabase', '@', 3) AS "empty string";
 
-select split_part('@joeuser@mydatabase@','@',2) AS " joeuser ";
+SELECT
+    split_part('@joeuser@mydatabase@', '@', 2) AS "joeuser";
 
 --
 -- test to_hex
 --
-select to_hex(256*256*256 - 1) AS " ffffff ";
+SELECT
+    to_hex(256 * 256 * 256 - 1) AS "ffffff";
 
-select to_hex(256::bigint*256::bigint*256::bigint*256::bigint - 1) AS " ffffffff ";
+SELECT
+    to_hex(256::bigint * 256::bigint * 256::bigint * 256::bigint - 1) AS "ffffffff";
 
 --
 -- MD5 test suite - from IETF RFC 1321
 -- (see: ftp://ftp.rfc-editor.org/in-notes/rfc1321.txt)
 --
-select md5('') = 'd41d8cd98f00b204e9800998ecf8427e' AS " TRUE ";
+SELECT
+    md5('') = 'd41d8cd98f00b204e9800998ecf8427e' AS "TRUE";
 
-select md5('a') = '0cc175b9c0f1b6a831c399e269772661' AS " TRUE ";
+SELECT
+    md5('a') = '0cc175b9c0f1b6a831c399e269772661' AS "TRUE";
 
-select md5('abc') = '900150983cd24fb0d6963f7d28e17f72' AS " TRUE ";
+SELECT
+    md5('abc') = '900150983cd24fb0d6963f7d28e17f72' AS "TRUE";
 
-select md5('message digest') = 'f96b697d7cb7938d525a2f31aaf161d0' AS " TRUE ";
+SELECT
+    md5('message digest') = 'f96b697d7cb7938d525a2f31aaf161d0' AS "TRUE";
 
-select md5('abcdefghijklmnopqrstuvwxyz') = 'c3fcd3d76192e4007dfb496cca67e13b' AS " TRUE ";
+SELECT
+    md5('abcdefghijklmnopqrstuvwxyz') = 'c3fcd3d76192e4007dfb496cca67e13b' AS "TRUE";
 
-select md5('ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789') = 'd174ab98d277d9f5a5611c2c9f419d9f' AS " TRUE ";
+SELECT
+    md5('ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789') = 'd174ab98d277d9f5a5611c2c9f419d9f' AS "TRUE";
 
-select md5('12345678901234567890123456789012345678901234567890123456789012345678901234567890') = '57edf4a22be3c955ac49da2e2107b67a' AS " TRUE ";
+SELECT
+    md5('12345678901234567890123456789012345678901234567890123456789012345678901234567890') = '57edf4a22be3c955ac49da2e2107b67a' AS "TRUE";
 
-select md5(''::bytea) = 'd41d8cd98f00b204e9800998ecf8427e' AS " TRUE ";
+SELECT
+    md5(''::bytea) = 'd41d8cd98f00b204e9800998ecf8427e' AS "TRUE";
 
-select md5('a'::bytea) = '0cc175b9c0f1b6a831c399e269772661' AS " TRUE ";
+SELECT
+    md5('a'::bytea) = '0cc175b9c0f1b6a831c399e269772661' AS "TRUE";
 
-select md5('abc'::bytea) = '900150983cd24fb0d6963f7d28e17f72' AS " TRUE ";
+SELECT
+    md5('abc'::bytea) = '900150983cd24fb0d6963f7d28e17f72' AS "TRUE";
 
-select md5('message digest'::bytea) = 'f96b697d7cb7938d525a2f31aaf161d0' AS " TRUE ";
+SELECT
+    md5('message digest'::bytea) = 'f96b697d7cb7938d525a2f31aaf161d0' AS "TRUE";
 
-select md5('abcdefghijklmnopqrstuvwxyz'::bytea) = 'c3fcd3d76192e4007dfb496cca67e13b' AS " TRUE ";
+SELECT
+    md5('abcdefghijklmnopqrstuvwxyz'::bytea) = 'c3fcd3d76192e4007dfb496cca67e13b' AS "TRUE";
 
-select md5('ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789'::bytea) = 'd174ab98d277d9f5a5611c2c9f419d9f' AS " TRUE ";
+SELECT
+    md5('ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789'::bytea) = 'd174ab98d277d9f5a5611c2c9f419d9f' AS "TRUE";
 
-select md5('12345678901234567890123456789012345678901234567890123456789012345678901234567890'::bytea) = '57edf4a22be3c955ac49da2e2107b67a' AS " TRUE ";
+SELECT
+    md5('12345678901234567890123456789012345678901234567890123456789012345678901234567890'::bytea) = '57edf4a22be3c955ac49da2e2107b67a' AS "TRUE";
 
 --
 -- SHA-2
@@ -579,7 +628,7 @@ SELECT
     'a\bcd' AS f1,
     'a\b''cd' AS f2,
     'a\b''''cd' AS f3,
-    'abcd\'   as f4, ' ab\' 'cd' AS f5,
+    'abcd\'   as f4, ' ab\''cd' AS f5,
     '\\' AS f6;
 
 SET standard_conforming_strings = OFF;
@@ -600,7 +649,7 @@ SELECT
     'a\bcd' AS f1,
     'a\b''cd' AS f2,
     'a\b''''cd' AS f3,
-    'abcd\'   as f4, ' ab\' 'cd' AS f5,
+    'abcd\'   as f4, ' ab\''cd' AS f5,
     '\\' AS f6;
 
 SET standard_conforming_strings = OFF;
@@ -628,7 +677,7 @@ SELECT
     lpad('hi', 5);
 
 SELECT
-    lpad('hi', - 5, 'xy');
+    lpad('hi', -5, 'xy');
 
 SELECT
     lpad('hello', 2);
@@ -643,7 +692,7 @@ SELECT
     rpad('hi', 5);
 
 SELECT
-    rpad('hi', - 5, 'xy');
+    rpad('hi', -5, 'xy');
 
 SELECT
     rpad('hello', 2);
@@ -676,7 +725,7 @@ SELECT
     repeat('Pg', 4);
 
 SELECT
-    repeat('Pg', - 4);
+    repeat('Pg', -4);
 
 SELECT
     trim(E'\\000'::bytea FROM E'\\000Tom\\000'::bytea);
