@@ -685,7 +685,7 @@ WHERE
 
 CREATE RULE shipped_view_insert AS ON INSERT TO shipped_view
     DO INSTEAD
-    INSERT INTO shipped VALUES ('wt', new.ordnum, new.partnum, new.value);
+    INSERT INTO shipped VALUES ('wt', NEW.ordnum, NEW.partnum, NEW.value);
 
 INSERT INTO parts (partnum,
     COST)
@@ -694,7 +694,8 @@ INSERT INTO parts (partnum,
 INSERT INTO shipped_view (ordnum, partnum, value)
     VALUES (0, 1, (
             SELECT
-                COST FROM parts
+                COST
+            FROM parts
             WHERE
                 partnum = '1'));
 
@@ -708,10 +709,10 @@ CREATE RULE shipped_view_update AS ON UPDATE
         DO INSTEAD
         UPDATE
             shipped SET
-            partnum = new.partnum,
-            value = new.value WHERE
-            ttype = new.ttype
-            AND ordnum = new.ordnum;
+            partnum = NEW.partnum,
+            value = NEW.value WHERE
+            ttype = NEW.ttype
+            AND ordnum = NEW.ordnum;
 
 UPDATE
     shipped_view
@@ -1048,13 +1049,13 @@ CREATE temp TABLE upsert (
 
 INSERT INTO upsert
     VALUES (1, 'val')
-ON CONFLICT (KEY)
+ON CONFLICT (key)
     DO UPDATE SET
         val = 'not seen';
 
 INSERT INTO upsert
     VALUES (1, 'val')
-ON CONFLICT (KEY)
+ON CONFLICT (key)
     DO UPDATE SET
         val = 'seen with subselect ' || (
             SELECT
@@ -1078,7 +1079,7 @@ WITH aa AS (
     LIMIT 1)
     INSERT INTO upsert
         VALUES (1, 'x'), (999, 'y')
-    ON CONFLICT (KEY)
+    ON CONFLICT (key)
         DO UPDATE SET
             val = (
                 SELECT
@@ -1461,7 +1462,7 @@ CREATE FUNCTION tattle (x int, y int)
     LANGUAGE plpgsql
     AS $$
 BEGIN
-    RAISE notice 'x = %, y = %', x, y;
+    RAISE NOTICE 'x = %, y = %', x, y;
     RETURN x > y;
 END
 $$;
