@@ -208,8 +208,7 @@ SELECT
 FROM
     FLOAT8_TBL
 WHERE
-    f1 BETWEEN - 1e6
-    AND 1e6
+    f1 BETWEEN - 1e6 AND 1e6
 UNION
 SELECT
     f1
@@ -1269,7 +1268,7 @@ $$;
 
 CREATE temp TABLE t3 AS
 SELECT
-    generate_series(- 1000, 1000) AS x;
+    generate_series(-1000, 1000) AS x;
 
 CREATE INDEX t3i ON t3 (expensivefunc (x));
 
