@@ -202,7 +202,7 @@ WHERE
     unique2 < 10;
 
 SELECT
-    lead(ten * 2, 1, - 1) OVER (PARTITION BY four ORDER BY ten),
+    lead(ten * 2, 1, -1) OVER (PARTITION BY four ORDER BY ten),
     ten,
     four
 FROM
@@ -348,7 +348,8 @@ ORDER BY
 SELECT
     lead(ten, (
             SELECT
-                two FROM tenk1
+                two
+            FROM tenk1
             WHERE
                 s.unique2 = unique2)) OVER (PARTITION BY four ORDER BY ten)
 FROM
@@ -1091,7 +1092,7 @@ SELECT
     x,
     last_value(x) OVER (ORDER BY x::smallint DESC RANGE BETWEEN CURRENT ROW AND 2147450885 FOLLOWING)
 FROM
-    generate_series(- 32766, - 32764) x;
+    generate_series(-32766, -32764) x;
 
 SELECT
     x,
@@ -1103,7 +1104,7 @@ SELECT
     x,
     last_value(x) OVER (ORDER BY x DESC RANGE BETWEEN CURRENT ROW AND 5 FOLLOWING)
 FROM
-    generate_series(- 2147483646, - 2147483644) x;
+    generate_series(-2147483646, -2147483644) x;
 
 SELECT
     x,
@@ -1115,7 +1116,7 @@ SELECT
     x,
     last_value(x) OVER (ORDER BY x DESC RANGE BETWEEN CURRENT ROW AND 5 FOLLOWING)
 FROM
-    generate_series(- 9223372036854775806, - 9223372036854775804) x;
+    generate_series(-9223372036854775806, -9223372036854775804) x;
 
 -- Test in_range for other numeric datatypes
 CREATE temp TABLE numerics (
@@ -1127,7 +1128,7 @@ CREATE temp TABLE numerics (
 
 INSERT INTO numerics
     VALUES (0, '-infinity', '-infinity', '-1000'), -- numeric type lacks infinities
-    (1, - 3, - 3, - 3), (2, - 1, - 1, - 1), (3, 0, 0, 0), (4, 1.1, 1.1, 1.1), (5, 1.12, 1.12, 1.12), (6, 2, 2, 2), (7, 100, 100, 100), (8, 'infinity', 'infinity', '1000'), (9, 'NaN', 'NaN', 'NaN');
+    (1, -3, -3, -3), (2, -1, -1, -1), (3, 0, 0, 0), (4, 1.1, 1.1, 1.1), (5, 1.12, 1.12, 1.12), (6, 2, 2, 2), (7, 100, 100, 100), (8, 'infinity', 'infinity', '1000'), (9, 'NaN', 'NaN', 'NaN');
 
 SELECT
     id,
@@ -1352,14 +1353,14 @@ FROM
     empsalary;
 
 SELECT
-    max(enroll_date) OVER (ORDER BY salary RANGE BETWEEN - 1 PRECEDING AND 2 FOLLOWING EXCLUDE TIES),
+    max(enroll_date) OVER (ORDER BY salary RANGE BETWEEN -1 PRECEDING AND 2 FOLLOWING EXCLUDE TIES),
     salary,
     enroll_date
 FROM
     empsalary;
 
 SELECT
-    max(enroll_date) OVER (ORDER BY salary RANGE BETWEEN 1 PRECEDING AND - 2 FOLLOWING EXCLUDE TIES),
+    max(enroll_date) OVER (ORDER BY salary RANGE BETWEEN 1 PRECEDING AND -2 FOLLOWING EXCLUDE TIES),
     salary,
     enroll_date
 FROM
@@ -2069,10 +2070,10 @@ CREATE AGGREGATE logging_agg_strict_initcond (anyelement) (
 
 -- test strict and non-strict cases
 SELECT
-    p::text || ',' || i::text || ':' || COALESCE(v::text, 'NULL') AS ROW,
+    p::text || ',' || i::text || ':' || COALESCE(v::text, 'NULL') AS row,
     logging_agg_nonstrict (v) OVER wnd AS nstrict,
     logging_agg_nonstrict_initcond (v) OVER wnd AS nstrict_init,
-    logging_agg_strict (v::text) OVER wnd AS STRICT,
+    logging_agg_strict (v::text) OVER wnd AS strict,
     logging_agg_strict_initcond (v) OVER wnd AS strict_init
 FROM (
     VALUES (1, 1, NULL),
@@ -2095,7 +2096,7 @@ SELECT
         COALESCE(v::text, 'NULL')
     ELSE
         '-'
-    END AS ROW,
+    END AS row,
     logging_agg_nonstrict (v) FILTER (WHERE f) OVER wnd AS nstrict_filt,
     logging_agg_nonstrict_initcond (v) FILTER (WHERE f) OVER wnd AS nstrict_init_filt,
     logging_agg_strict (v::text) FILTER (WHERE f) OVER wnd AS strict_filt,
@@ -2117,7 +2118,7 @@ ORDER BY
 
 -- test that volatile arguments disable moving-aggregate mode
 SELECT
-    i::text || ':' || COALESCE(v::text, 'NULL') AS ROW,
+    i::text || ':' || COALESCE(v::text, 'NULL') AS row,
     logging_agg_strict (v::text) OVER wnd AS inverse,
     logging_agg_strict (v::text || CASE WHEN random() < 0 THEN
             '?'
@@ -2133,7 +2134,7 @@ ORDER BY
     i;
 
 SELECT
-    i::text || ':' || COALESCE(v::text, 'NULL') AS ROW,
+    i::text || ':' || COALESCE(v::text, 'NULL') AS row,
     logging_agg_strict (v::text) FILTER (WHERE TRUE) OVER wnd AS inverse,
     logging_agg_strict (v::text) FILTER (WHERE random() >= 0) OVER wnd AS noinverse
 FROM (
