@@ -39,7 +39,7 @@ VALUES (
     8,
     9);
 
-CREATE cast (INT8 AS int8alias1) WITHOUT FUNCTION;
+CREATE CAST (INT8 AS int8alias1) WITHOUT FUNCTION;
 
 CREATE TABLE test11a AS (
     SELECT
